@@ -1,27 +1,27 @@
 function [r2, h, count, err] = carttocart2(t, r)
 %CARTTOCART2  Find the closest point on an ellipsoid
 %
-%   [r2, h] = CARTTOCART2(t, r)
-%   [r2, h, count, err] = CARTTOCART2(t, r)
+%   [R2, h] = CARTTOCART2(t, R)
+%   [R2, h, count, err] = CARTTOCART2(t, R)
 %
 %   Input:
 %     t the triaxial ellipsoid object
-%     r an n x 3 array of cartesian points
+%     R an n x 3 array of cartesian points
 %   Output:
-%     r2 an n x 3 array of the closest cartesian points lying on t
-%     h an n x 1 array of the directed distances, heights, from r2 to r
+%     R2 an n x 3 array of the closest cartesian points lying on t
+%     h an n x 1 array of the directed distances, heights, from R2 to R
 %     count an n x 1 array of the number of Newton's iterations
 %     err an n x 1 array of the error in the function
 %
 %   See also CART2TOCART, CART2TOGEOD, CARTTOGEOD
 
-% Copyright (c) Charles Karney (2024) <karney@alum.mit.edu>.
+% Copyright (c) Charles Karney (2024-2025) <karney@alum.mit.edu>.
 
 % The formulation is due to Ligas, Stud. Geophys. Geod. (2012).  The major
 % difference is to use an improved starting guess for Newton's method which
 % guarantees convergence.  Panou and Korakitis, J. Geod. (2022) use the
 % bisection method to solve the same equation; but this requires many more
-% iterations to converge compared to Newton's method.  Seom other points:
+% iterations to converge compared to Newton's method.  Some other points:
 %
 % * the method used here is simpler that PK (2022), in that there's no need
 %   to treat special cases separately (indeed the method could easily be
@@ -56,12 +56,12 @@ function [r2, h, count, err] = carttocart2(t, r)
     % We're done if f(p) <= 0 on initial guess; this can happens when z = 0.
     % However, since Newton converges from below, any negative f(p)
     % indicates convergence.
-    l = ~(fv <= tol^2);
+    l = l & ~(fv <= tol^2);
     d = -fv./fp;
     p(l) = p(l) + d(l);
     l = l & ~c;
     % converged if fv <= 8*eps (after first iteration) or
-    % d <= max(eps, |p|) * tol and d <= od.
+    % d <= max(sqrt(eps), |p|) * tol and d <= od.
     % N.B. d and od are always positive.
     c = d <= max(t.b^2 * sqrt(eps), p) * tol & d < od;
     if i > 1
@@ -81,8 +81,8 @@ function [r2, h, count, err] = carttocart2(t, r)
     if axes2(2) == 0                     % sphere or prolate
       r2(l, 2) = r(l, 2);
     end
-    r2(l, 3) = t.axes(3) * r(l, 3) .* ...
-        sqrt(1 - (r2(l, 1)/t.axes(1)).^2 + (r2(l, 2)/t.axes(2)).^2);
+    r2(l, 3) = t.axes(3) * signx(r(l, 3)) .* ...
+        sqrt(1 - (r2(l, 1)/t.axes(1)).^2 - (r2(l, 2)/t.axes(2)).^2);
   end
   h = (p - t.axes(3)^2) .* vecabs(r2 ./ t.axes.^2);
 end
