@@ -6,10 +6,11 @@ function doc
 %   prints summary documentation on the TRIAXIAL class
 %
 %   t = TRIAXIAL([a, b, c]) -- set up ellipsoid in terms of the semiaxes.
+%   t = TRIAXIAL([b, e2, k2, kp2]) -- or in terms of ellipsoid parameters.
 %
 %   In function names and function parameters
-%   * cart or r refers to arbitrary points in space expressed as [x, y, z];
-%   * cart2 or r2 refers to points on the surface of the ellipsoid;
+%   * cart or R refers to arbitrary points in space expressed as [X, Y, Z];
+%   * cart2 or R2 refers to points on the surface of the ellipsoid;
 %   * geod specifies a point in geodetic coordinates [phi, lam];
 %   * param specifies a point in parametric coordinates [phip, lamp];
 %   * geocen specifies a point in geocentric coordinates [phic, lamc];
@@ -22,13 +23,22 @@ function doc
 %   If the third element, u = minor semiaxis of the confocal ellipsoid, of
 %   ellip3 is omitted, it is taken as the minor semiaxis of the ellipsoid.
 %
-%   On the surface of an ellipsoid, specify a direction as a unit velocity v
+%   On the surface of an ellipsoid, specify a direction as a unit velocity V
 %   in cartesian coordinates, or as an azimuth, alp, clockwise from a line
 %   of constant ellipsoidal longitude, omg.
 %
 %   All angles are given in degrees.  All distances are given in the units
 %   of the semiaxes.
 %
+%   The coordinate conversions are documented in
+%
+%     C. F. F. Karney,
+%     Jacobi's solution for geodesics on a triaxial ellipsoid (2025).
+%     https://arxiv.org/abs/arxiv:2511.01621
+%
+%   This paper uses a different method for solving the direct geodesic
+%   problem; however, the solution using ODEs is discussed.
+%
 %   The accuracy of the geodesic routines for can be found using the
 %   test set available at
 %
@@ -47,33 +57,33 @@ function doc
 %
 %   Conversion routines
 %
-%     [r2, h] = t.CARTTOCART2(r)
-%     r = t.CART2TOCART(r2, h)
+%     [R2, h] = t.CARTTOCART2(R)
+%     R = t.CART2TOCART(R2, h)
 %
-%     [ellip, alp] = t.CART2TOELLIP(r, v)
-%     [r, v] = t.ELLIPTOCART2(ellip, alp)
-%     ellip3 = t.CARTTOELLIP(r)
-%     r = t.ELLIPTOCART(ellip)
+%     [ellip, alp] = t.CART2TOELLIP(R, V)
+%     [R, V] = t.ELLIPTOCART2(ellip, alp)
+%     ellip3 = t.CARTTOELLIP(R)
+%     R = t.ELLIPTOCART(ellip)
 %
-%     geod = t.CART2TOGEOD(r)
-%     geod3 = t.CARTTOGEOD(r)
-%     r = t.GEODTOCART(geod3)
+%     geod = t.CART2TOGEOD(R)
+%     geod3 = t.CARTTOGEOD(R)
+%     R = t.GEODTOCART(geod3)
 %
-%     param = t.CART2TOPARAM(r)
-%     r = t.PARAMTOCART2(param)
+%     param = t.CART2TOPARAM(R)
+%     R = t.PARAMTOCART2(param)
 %
-%     geocen = t.CART2TOGEOCEN(r)
-%     r = t.GEOCENTOCART2(geocen)
+%     geocen = t.CART2TOGEOCEN(R)
+%     R = t.GEOCENTOCART2(geocen)
 %
 %     out = t.CONVERT(in, from, to)
 %
 %   Random points on the ellipsoid (and directions)
-%     [r, v] = t.CART2RAND(n)
+%     [R, V] = t.CART2RAND(n)
 %
 %   Geodesic calculations
 %     [pos2, dir2] = t.RECKON(pos1, dir1, s12)
 %     [s12, dir1, dir2] = t.DISTANCE(pos1, pos2)
-%     [r2, v2, s12] = t.HYBRID(r1, v1, cond)
+%     [R2, V2, s12] = t.HYBRID(R1, V1, cond)
 %
 %   Other
 %     CART2NORM -- force points to lie on the surface
@@ -88,5 +98,5 @@ function doc
 
 % Copyright (c) Charles Karney (2024) <karney@alum.mit.edu>.
 
-  help triaxial/doc
+  help @triaxial/doc
 end
